==> UIAPlatform-1.0.0-rc1-sources.jar: com/sun/glass/ui/uia/provider/TextEditProviderAdapter.java <==
/*
 * -----------------------------------------------------------------
 * Copyright (c) 2021 BestSolution.at EDV Systemhaus GmbH
 * All Rights Reserved.
 *
 * BestSolution.at MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE  OR NON - INFRINGEMENT.
 * BestSolution.at SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY
 * LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS
 * SOFTWARE OR ITS DERIVATIVES.
 *
 * This software is released under the terms of the
 *
 *                  "GNU General Public License, Version 2 
 *                         with classpath exception"
 *
 * and may only be distributed and used under the terms of the
 * mentioned license. You should have received a copy of the license
 * along with this software product, if not you can download it from
 * http://www.gnu.org/licenses/gpl.html
 * ----------------------------------------------------------------
 */
package com.sun.glass.ui.uia.provider;

import com.sun.glass.ui.uia.ProxyAccessible;
import com.sun.glass.ui.uia.ProxyTextRangeProvider;

import javafx.uia.ITextEditProvider;
import javafx.uia.ITextRangeProvider;

public class TextEditProviderAdapter extends BaseAdapter<ITextEditProvider> implements NativeITextEditProvider {

    public TextEditProviderAdapter(ProxyAccessible accessible, ITextEditProvider provider) {
        super(accessible, provider);
    }

    private long toNative(ITextRangeProvider provider) {
        ProxyTextRangeProvider proxy = new ProxyTextRangeProvider(accessible, provider);
        return proxy.getNativeProvider();
    }

    @Override
    public long GetActiveComposition() {
        return toNative(provider.GetActiveComposition());
    }

    @Override
    public long GetConversionTarget() {
        return toNative(provider.GetConversionTarget());
    }

}

==> UIAPlatform-999.0.0-20220525.153239-26-sources.jar: com/sun/glass/ui/uia/provider/TextEditProviderAdapter.java <==
/*
 * -----------------------------------------------------------------
 * Copyright (c) 2021 BestSolution.at EDV Systemhaus GmbH
 * All Rights Reserved.
 *
 * BestSolution.at MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE  OR NON - INFRINGEMENT.
 * BestSolution.at SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY
 * LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS
 * SOFTWARE OR ITS DERIVATIVES.
 *
 * This software is released under the terms of the
 *
 *                  "GNU General Public License, Version 2 
 *                         with classpath exception"
 *
 * and may only be distributed and used under the terms of the
 * mentioned license. You should have received a copy of the license
 * along with this software product, if not you can download it from
 * http://www.gnu.org/licenses/gpl.html
 * ----------------------------------------------------------------
 */
package com.sun.glass.ui.uia.provider;

import com.sun.glass.ui.uia.ProxyAccessible;

import javafx.uia.ITextEditProvider;

public class TextEditProviderAdapter extends BaseAdapter<ITextEditProvider> implements NativeITextEditProvider {

    public TextEditProviderAdapter(ProxyAccessible accessible, ITextEditProvider provider) {
        super(accessible, provider);
    }

    @Override
    public long GetActiveComposition() {
        return wrapNative(provider.GetActiveComposition());
    }

    @Override
    public long GetConversionTarget() {
        return wrapNative(provider.GetConversionTarget());
    }

}
